@@ -1,5 +1,5 @@
 /* Version and patchlevel for TimeTracker */
 #define PATCHLEVEL 98
 #define VERSION 1
-#define COMMENT ""
+#define COMMENT "Patch 1"
 
