@@ -1,36 +1,49 @@
-/* TIMETRACKER - the Time Usage Meter */
-/* By Harald Tveit Alvestrand, UNINETT, Norway
+/*
+ * TIMETRACKER - the Time Usage Meter 
+ */
+/*
+ * By Harald Tveit Alvestrand, UNINETT, Norway
+ * 
+ * This code has NO guarantees; use it as you see fit.
+ * See the README file for details.
+ * 
+ * 
+ */
+/*
+ * Keeping the RCS keyword around 
+ */
+static char     rcsid[] = "$Id: titrax.c,v 1.26 1996/04/03 09:48:41 hta Exp hta $";
+static char     rcsdate[] = "$Date: 1996/04/03 09:48:41 $";
 
-   This code has NO guarantees; use it as you see fit.
-   See the README file for details.
-
-
-*/
-/* Keeping the RCS keyword around */
-static char     rcsid[] = "$Id: titrax.c,v 1.24 1995/10/10 14:09:28 hta Exp $";
-static char     rcsdate[] = "$Date: 1995/10/10 14:09:28 $";
-
-/* Avoid "variable defined but never used" complaint - but requires ANSI C */
+/*
+ * Avoid "variable defined but never used" complaint - but requires ANSI C 
+ */
 #ifdef __STDC__
 #define USE(var) \
             static void * use_##var[] = {&use_##var, (void *) &var}
 USE(rcsid);
 #endif
 
-/* ------------ Shared definitions --------------- */
+/*
+ * ------------ Shared definitions --------------- 
+ */
 #include "titrax.h"
 #include "patchlevel.h"
-/* The icon bitmap */
+/*
+ * The icon bitmap 
+ */
 #include "titrax.xbm"
 
 
-/* ------------- APPLICATION RESOURCES AND OPTIONS -------------- */
+/*
+ * ------------- APPLICATION RESOURCES AND OPTIONS -------------- 
+ */
 
 #ifdef DEBUG
-static char     TimeTrackerClassName[] = "DebugTimeTracker";
+static char     TimeTrackerClassName[] = "DebugTitrax";
 
 #else
-static char     TimeTrackerClassName[] = "TimeTracker";
+static char     TimeTrackerClassName[] = "Titrax";
 
 #endif
 
@@ -43,16 +56,24 @@ String          fallbackResources[] =
 int             pmin, phour;
 
 struct _resources {
-   Boolean         project_icon_name;	/* put current project in icon name */
-   char           *icon_prefix;	/* fixed prefix in icon name */
-   Boolean         start_paused;/* start in paused mode */
-   char           *auto_pause;	/* Time when pause is automatic */
-   char           *TimeTracker_directory;	/* fixed prefix in icon name */
+   Boolean         project_icon_name;	/*
+					 * put current project in icon name 
+					 */
+   char           *icon_prefix;	/*
+				 * fixed prefix in icon name 
+				 */
+   Boolean         start_paused;	/*
+					 * start in paused mode 
+					 */
+   char           *auto_pause;	/*
+				 * Time when pause is automatic 
+				 */
+   char           *TimeTracker_directory;	/*
+						 * fixed prefix in icon name 
+						 */
    Boolean         appDefaultsLoaded;
    char           *errorMessage;
-}
-
-app_resources;
+} app_resources;
 
 #define Offset(field) XtOffsetOf(struct _resources, field)
 
@@ -92,7 +113,9 @@ usage: TimeTracker [-pi]                  ... put project in icon name\n\
    exit(1);
 }
 
-/* ------------ GLOBAL VARIABLES ----------------- */
+/*
+ * ------------ GLOBAL VARIABLES ----------------- 
+ */
 
 String         *timeList = NULL;
 String         *nameList = NULL;
@@ -100,10 +123,34 @@ int            *timeUsed = NULL;
 int             totaltime;
 int             adjustedtime;
 int             incPlus = 10, incMinus = -10;
-int             lockfd;		/* Locking file descriptor */
-char            lockfilename[MAXPATHLEN];	/* Lockfile name */
+int             lockfd;		/*
+
+				 * 
+				 * * 
+				 * * * 
+				 * * * * 
+				 * * * * * 
+				 * * * * * * Locking file descriptor 
+				 */
+char            lockfilename[MAXPATHLEN];	/*
+
+						 * 
+						 * * 
+						 * * * 
+						 * * * * 
+						 * * * * * 
+						 * * * * * * Lockfile name 
+						 */
 char            title[80];
-char            msgbuf[1000];	/* Temp storage for error messages */
+char            msgbuf[1000];	/*
+
+				 * 
+				 * * 
+				 * * * 
+				 * * * * 
+				 * * * * * 
+				 * * * * * * Temp storage for error messages 
+				 */
 int             markedProject;
 
 
@@ -121,20 +168,46 @@ Widget          commandBox;
 Widget          totalDisplay;
 Widget          messageOkButton;
 
-char            TimeTrackerdirectory[MAXPATHLEN];	/* file name prefix to use */
+char            TimeTrackerdirectory[MAXPATHLEN];	/*
+
+							 * 
+							 * * 
+							 * * * 
+							 * * * * 
+							 * * * * * 
+							 * * * * * * file name prefix to use 
+							 */
 int             lastDate, lastTime;
-char           *timestring;	/* Non-NULL when used as an EDITOR */
+char           *timestring;	/*
+
+				 * 
+				 * * 
+				 * * * 
+				 * * * * 
+				 * * * * * 
+				 * * * * * * Non-NULL when used as an EDITOR 
+				 */
 static Pixmap   iconP;
 
 
-void            timeshavechanged();	/* Declared later in this file */
+void            timeshavechanged();		/*
+
+						 * 
+						 * * 
+						 * * * 
+						 * * * * 
+						 * * * * * 
+						 * * * * * * Declared later in this file 
+						 */
 void            DeleteProject();
 int             testfortime();
 int             TestForNoOldProject();
 void            printtime();
 void            SomethingWrong();
 
-/* ------------- UTILITY FUNCTIONS -------------- */
+/*
+ * ------------- UTILITY FUNCTIONS -------------- 
+ */
 /*
  *  Set up the TimeTracker file directory based on TimeTrackerdirectory resource,
  *  a leading '~' is expanded to $HOME
@@ -147,15 +220,19 @@ fix_TimeTracker_directory()
    struct stat     buf;
    String          s;
    int             ret;
+   int             implicit;
 
    TimeTrackerdirectory[0] = '\0';
+   implicit = 0;
    if ((s = getenv("TIMETRACKDIR"))) {
       if (s[0] == '~')
 	 sprintf(TimeTrackerdirectory, "%s%s", getenv("HOME"), &s[1]);
       else
 	 sprintf(TimeTrackerdirectory, "%s", s);
    } else if ((s = getenv("TIMEXDIR"))) {
-      /* Backwards compatibility with old program name */
+      /*
+       * Backwards compatibility with old program name 
+       */
       if (s[0] == '~')
 	 sprintf(TimeTrackerdirectory, "%s%s", getenv("HOME"), &s[1]);
       else
@@ -166,14 +243,23 @@ fix_TimeTracker_directory()
 		 getenv("HOME"), &app_resources.TimeTracker_directory[1]);
       else
 	 strcpy(TimeTrackerdirectory, app_resources.TimeTracker_directory);
-   } else
+   } else {
       sprintf(TimeTrackerdirectory, "%s/.TimeTracker", getenv("HOME"));
+      implicit = 1;
+   }
 
    ret = stat(TimeTrackerdirectory, &buf);
-   if (ret < 0 && errno == ENOENT) {
-      /* Check for the Timex directory from the previous name */
-      sprintf(TimeTrackerdirectory, "%s/.timex", getenv("HOME"));
+   if (ret < 0 && errno == ENOENT && implicit) {
+      /*
+       * Check for the Timex directory from the previous name 
+       */
+      char            timexdirectory[MAXPATHLEN];
+
+      sprintf(timexdirectory, "%s/.timex", getenv("HOME"));
       ret = stat(TimeTrackerdirectory, &buf);
+      if (ret == 0) {
+	 strcpy(TimeTrackerdirectory, timexdirectory);
+      }
    }
    if (ret < 0) {
       if (errno == ENOENT) {
@@ -186,7 +272,9 @@ fix_TimeTracker_directory()
 	 }
 	 sprintf(msgbuf, "Created TimeTracker directory %s", TimeTrackerdirectory);
 	 MessageBox(toplevel, msgbuf);
-	 ret = stat(TimeTrackerdirectory, &buf);	/* stat the new dir */
+	 ret = stat(TimeTrackerdirectory, &buf);	/*
+							 * stat the new dir 
+							 */
       } else {
 	 sprintf(msgbuf, "TimeTracker: unable to stat directory %s\n",
 		 TimeTrackerdirectory);
@@ -202,7 +290,9 @@ fix_TimeTracker_directory()
    return;
 }
 
-/* Handling of dayfiles */
+/*
+ * Handling of dayfiles 
+ */
 
 char           *
 dayfilename(dayoffset)
@@ -217,7 +307,9 @@ dayfilename(dayoffset)
    } else {
       time_t          now = time((time_t *) 0);
 
-      now += dayoffset * 24 * 60 * SECONDSPERMINUTE;	/* Add in adjusted day */
+      now += dayoffset * 24 * 60 * SECONDSPERMINUTE;	/*
+							 * Add in adjusted day 
+							 */
       today = *(localtime(&now));
 
       (void) sprintf(filename, "%.*s/%04d-%02d-%02d",
@@ -227,7 +319,9 @@ dayfilename(dayoffset)
    return filename;
 }
 
-/* Save current listing to a dayfile */
+/*
+ * Save current listing to a dayfile 
+ */
 void
 save(dayoffset, reason)
      int dayoffset;
@@ -286,15 +380,23 @@ fetchdayfile(filename)
    int             scan, count;
    FILE           *infile;
 
-/* Add times from a previous incarnation of TimeTracker for today */
+/*
+ * Add times from a previous incarnation of TimeTracker for today 
+ */
    if ((infile = fopen(filename, "r")) == NULL) {
-      return 0;			/* No file found, assume fresh day */
+      return 0;			/*
+				 * No file found, assume fresh day 
+				 */
    }
-   /* Skip the header line */
+   /*
+    * Skip the header line 
+    */
    (void) fgets(buffer, sizeof(buffer), infile);
    while (fgets(buffer, sizeof(buffer), infile)) {
       if (buffer[0] == '#')
-	 continue;		/* Skip comment lines */
+	 continue;		/*
+				 * Skip comment lines 
+				 */
       count = sscanf(buffer, "%d:%d %[^\n]", &hours, &minutes, project);
       if (count < 3) {
 	 fprintf(stderr, "Bogus project line in dayfile: %s\n", buffer);
@@ -308,11 +410,15 @@ fetchdayfile(filename)
       }
       if (!nameList[scan]) {
 	 addDeadProject(project, hours * 60 + minutes);
-/*	 fprintf(stderr, "Bogus project: %s\n", project); */
+/*
+ * fprintf(stderr, "Bogus project: %s\n", project); 
+ */
       }
    }
    fclose(infile);
-   /* at this time (no other), reset totaltime */
+   /*
+    * at this time (no other), reset totaltime 
+    */
    resumtimes();
    totaltime = adjustedtime;
    adjustedtime = 0;
@@ -329,7 +435,9 @@ addprevtimes()
    return fetchdayfile(filename);
 }
 
-/* Ensure that only 1 copy of TimeTracker runs at any one time */
+/*
+ * Ensure that only 1 copy of TimeTracker runs at any one time 
+ */
 int
 lockTimeTracker()
 {
@@ -382,7 +490,9 @@ unlockTimeTracker()
    return 0;
 }
 
-/* Clear all the time-used fields */
+/*
+ * Clear all the time-used fields 
+ */
 void
 clear()
 {
@@ -392,7 +502,9 @@ clear()
       timeUsed[scan] = 0;
       timeList[scan][0] = '\0';
    }
-   /* Make the right width for the time list... */
+   /*
+    * Make the right width for the time list... 
+    */
    for (scan = 0; scan < TIMESTRINGLEN; scan++)
       timeList[0][scan] = ' ';
    timeList[0][TIMESTRINGLEN] = 0;
@@ -409,14 +521,22 @@ set_pause_time()
 		  &phour, &pmin);
    if (count != 2) {
       SomethingWrong("Auto Pause Time must be in a \"hh:mm\" 24 hour format\n");
-      /* Does not return */
+      /*
+       * Does not return 
+       */
    }
 }
 
-/* ------------- CALLBACK FUNCTIONS ------------ */
+/*
+ * ------------- CALLBACK FUNCTIONS ------------ 
+ */
 
-/* Callback function: Desctruction completed */
-/*ARGSUSED*/
+/*
+ * Callback function: Desctruction completed 
+ */
+/*
+ * ARGSUSED
+ */
 void
 destructioncompleted(widget, client_data, call_data)
      Widget widget;
@@ -427,7 +547,9 @@ destructioncompleted(widget, client_data, call_data)
    exit(0);
 }
 
-/* Fatal error handler - try to save and die */
+/*
+ * Fatal error handler - try to save and die 
+ */
 void
 gaspanddie(str)
      String str;
@@ -441,19 +563,25 @@ gaspanddie(str)
    exit(1);
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 int
 IOErrorHandler(display)
      Display *display;
 {
    gaspanddie("fatal X I/O error");
-   return 0;			/* make Lint happy */
+   return 0;			/*
+				 * make Lint happy 
+				 */
 }
 
 void
 signalhandler(sig)
      int sig;
-{				/* Yes, I know: it has more parameters */
+{				/*
+				 * Yes, I know: it has more parameters 
+				 */
    if (sig == SIGHUP)
       gaspanddie("HANGUP signal");
    if (sig == SIGINT)
@@ -468,7 +596,9 @@ signalhandler(sig)
 }
 
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 void
 savewhendying(widget, client_data, call_data)
      Widget widget;
@@ -481,7 +611,9 @@ savewhendying(widget, client_data, call_data)
 }
 
 
-/* ----------- DISPLAY HANDLING ------------- */
+/*
+ * ----------- DISPLAY HANDLING ------------- 
+ */
 
 /*
  *  Update the icon title to show current project name and time
@@ -496,7 +628,9 @@ set_icon_name(cur)
    char            icon_name[256], *names[1];
    XTextProperty   iconName;
 
-   /* Cannot set icon name before it is realized */
+   /*
+    * Cannot set icon name before it is realized 
+    */
    if (!XtIsRealized(toplevel))
       return;
    if (!app_resources.project_icon_name)
@@ -561,9 +695,13 @@ redisplayTime(cur)
 {
    if (cur >= 0) {
       printtime(cur);
-      /* Redisplay time, keep highlight */
+      /*
+       * Redisplay time, keep highlight 
+       */
       XawListHighlight(timelist_widget, cur);
-      /* Move highlight back to current project */
+      /*
+       * Move highlight back to current project 
+       */
       if (currentProject() != cur)
 	 if (currentProject() >= 0)
 	    XawListHighlight(timelist_widget, currentProject());
@@ -593,10 +731,16 @@ changeProject(adjustIncrement)
    redisplayTime(index);
 }
 
-/* ----------- REGISTERED ACTIONS ----------- */
+/*
+ * ----------- REGISTERED ACTIONS ----------- 
+ */
 
-/* Quit the show */
-/*ARGSUSED*/
+/*
+ * Quit the show 
+ */
+/*
+ * ARGSUSED
+ */
 static void
 Quit(widget, event, params, parmcount)
      Widget widget;
@@ -607,8 +751,12 @@ Quit(widget, event, params, parmcount)
    XtDestroyWidget(toplevel);
 }
 
-/* Callback function: Save */
-/*ARGSUSED*/
+/*
+ * Callback function: Save 
+ */
+/*
+ * ARGSUSED
+ */
 static void
 Save(widget, event, params, parmcount)
      Widget widget;
@@ -619,8 +767,12 @@ Save(widget, event, params, parmcount)
    save(0, "Save button hit");
 }
 
-/* Load file from disk */
-/*ARGSUSED*/
+/*
+ * Load file from disk 
+ */
+/*
+ * ARGSUSED
+ */
 static void
 Load(widget, event, params, parmcount)
      Widget widget;
@@ -631,7 +783,9 @@ Load(widget, event, params, parmcount)
    addprevtimes();
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 static void
 Increment(widget, event, params, parmcount)
      Widget widget;
@@ -646,7 +800,9 @@ Increment(widget, event, params, parmcount)
 }
 
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 static void
 Decrement(widget, event, params, parmcount)
      Widget widget;
@@ -660,7 +816,9 @@ Decrement(widget, event, params, parmcount)
       changeProject(incMinus);
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 static void
 Pause(widget, event, params, parmcount)
      Widget widget;
@@ -673,7 +831,9 @@ Pause(widget, event, params, parmcount)
    set_icon_name(-1);
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 static void
 Mark(widget, event, params, parmcount)
      Widget widget;
@@ -681,12 +841,16 @@ Mark(widget, event, params, parmcount)
      String *params;
      Cardinal *parmcount;
 {
-   /* Remember the current project for later Transfer */
+   /*
+    * Remember the current project for later Transfer 
+    */
    markedProject = currentProject();
 
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 static void
 Transfer(widget, event, params, parmcount)
      Widget widget;
@@ -715,7 +879,9 @@ Transfer(widget, event, params, parmcount)
       timeUsed[toindex] += increment;
       timeUsed[markedProject] -= increment;
       redisplayTime(toindex);
-      /* move focus back to markedProject */
+      /*
+       * move focus back to markedProject 
+       */
       XawListHighlight(list_widget, markedProject);
       redisplayTime(markedProject);
    } else {
@@ -727,7 +893,9 @@ Transfer(widget, event, params, parmcount)
 static void
 RegisterActions()
 {
-   /* Must be static to allow initialization */
+   /*
+    * Must be static to allow initialization 
+    */
    static XtActionsRec actions[] =
    {
       {"quit", Quit},
@@ -753,22 +921,30 @@ suicidecallback(widget, client_data, call_data)
 }
 
 
-/* Error handler for non-crash type errors: display an X message box */
+/*
+ * Error handler for non-crash type errors: display an X message box 
+ */
 void
 SomethingWrong(whatwentwrong)
      String whatwentwrong;
 {
-   /* Add a Quit action to the OK button in the messagebox */
+   /*
+    * Add a Quit action to the OK button in the messagebox 
+    */
    XtAddCallback(messageOkButton, XtNcallback, suicidecallback, NULL);
    MessageBox(toplevel, whatwentwrong);
-   /* Not sure if this is The Way, but we don't want to return */
+   /*
+    * Not sure if this is The Way, but we don't want to return 
+    */
    XtAppMainLoop(appContext);
 }
 
 
-/* Note the time, and maybe do specific actions.
-   Updates lastDate and lastTime.
-   Returns number of minutes since last called. */
+/*
+ * Note the time, and maybe do specific actions.
+ * Updates lastDate and lastTime.
+ * Returns number of minutes since last called. 
+ */
 int
 notethetime(maysave)
      int maysave;
@@ -793,7 +969,9 @@ notethetime(maysave)
    }
    rettime = (now / SECONDSPERMINUTE) - lastTime;
    if (maysave && today.tm_mday != lastDate) {
-      save(-1, "End of day");	/* Save YESTERDAY's times */
+      save(-1, "End of day");	/*
+				 * Save YESTERDAY's times 
+				 */
       clear();
       timeshavechanged();
 
@@ -807,11 +985,15 @@ notethetime(maysave)
    }
    lastDate = today.tm_mday;
    lastTime = now / SECONDSPERMINUTE;
-   return rettime;		/* Difference in minutes between now and prev
-				 * time */
+   return rettime;		/*
+				 * Difference in minutes between now and prev
+				 * * time 
+				 */
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 void
 clockTick(clientData, intervalID)
      XtPointer clientData;
@@ -828,7 +1010,9 @@ clockTick(clientData, intervalID)
       totaltime += increment;
       redisplayTime(cur);
    } else {
-      /* No time defined - note the time and throw away result */
+      /*
+       * No time defined - note the time and throw away result 
+       */
       (void) notethetime(True);
    }
    XtAppAddTimeOut(appContext,
@@ -836,7 +1020,9 @@ clockTick(clientData, intervalID)
 		   clockTick, clientData);
 }
 
-/*ARGSUSED*/
+/*
+ * ARGSUSED
+ */
 void
 saveOnclockTick(clientData, intervalID)
      XtPointer clientData;
@@ -848,7 +1034,9 @@ saveOnclockTick(clientData, intervalID)
 		   saveOnclockTick, clientData);
 }
 
-/* Times have been changed in the timelist. Update and set. */
+/*
+ * Times have been changed in the timelist. Update and set. 
+ */
 void
 timeshavechanged()
 {
@@ -858,9 +1046,13 @@ timeshavechanged()
 }
 
 
-/* Called on the Notify action of both list widgets:
-   Ensure that both lists are equally highlighted */
-/*ARGSUSED*/
+/*
+ * Called on the Notify action of both list widgets:
+ * Ensure that both lists are equally highlighted 
+ */
+/*
+ * ARGSUSED
+ */
 void
 notifycallback(widget, client_data, call_data)
      Widget widget;
@@ -876,7 +1068,9 @@ notifycallback(widget, client_data, call_data)
    XFree(cur);
 }
 
-/* A short VMS hack......be nice to other people */
+/*
+ * A short VMS hack......be nice to other people 
+ */
 void
 purge_working_set()
 {
@@ -930,14 +1124,20 @@ main(argc, argv)
    XtSetArg(wargs[n], XtNtitle, title);
    ++n;
    XtSetValues(toplevel, wargs, n);
-   /* Create the upper Form widget */
+   /*
+    * Create the upper Form widget 
+    */
    n = 0;
    topForm = XtCreateManagedWidget("form", formWidgetClass, toplevel, wargs, n);
    XtAddCallback(topForm, XtNdestroyCallback, destructioncompleted, NULL);
-   /* Create a message box for reporting non-X errors */
+   /*
+    * Create a message box for reporting non-X errors 
+    */
    initMessageBox();
 
-   /* Do non-X initialization */
+   /*
+    * Do non-X initialization 
+    */
    if (argc > 2)
       Usage();
 
@@ -957,7 +1157,9 @@ main(argc, argv)
    }
    if (makethelist() < 0) {
       SomethingWrong("Internal error: Makethelist failed");
-      exit(1);			/* if we get here */
+      exit(1);			/*
+				 * if we get here 
+				 */
    }
    if (timestring == NULL) {
       if (lockTimeTracker() < 0) {
@@ -966,32 +1168,44 @@ main(argc, argv)
       }
       notethetime(0);
    }
-   /* Create command box */
+   /*
+    * Create command box 
+    */
    n = 0;
    commandBox = XtCreateManagedWidget("command", boxWidgetClass,
 				      topForm, wargs, n);
-   /* Create commands */
+   /*
+    * Create commands 
+    */
    addButton(commandBox, "quit", NULL, NULL);
    addButton(commandBox, "plus", NULL, NULL);
    addButton(commandBox, "minus", NULL, NULL);
 
    n = 0;
    initprojectlisteditor();
-   /* A total-time display to the right of the commandbox */
+   /*
+    * A total-time display to the right of the commandbox 
+    */
    n = 0;
    XtSetArg(wargs[n], XtNfromHoriz, commandBox);
    ++n;
    XtSetArg(wargs[n], XtNlabel, "--:--+---");
    ++n;
-   /* just to get size right */
+   /*
+    * just to get size right 
+    */
    totalDisplay = XtCreateManagedWidget("total", labelWidgetClass,
 					topForm, wargs, n);
 
-   /* Create the save and load buttons only when editing */
+   /*
+    * Create the save and load buttons only when editing 
+    */
    if (timestring) {
       addButton(commandBox, "save", NULL, NULL);
       addButton(commandBox, "load", NULL, NULL);
-      /* Create a string in the right-hand corner */
+      /*
+       * Create a string in the right-hand corner 
+       */
       n = 0;
       XtSetArg(wargs[n], XtNlabel, timestring);
       ++n;
@@ -1002,27 +1216,37 @@ main(argc, argv)
       thisCommand = XtCreateManagedWidget("date", labelWidgetClass,
 					  topForm, wargs, n);
    } else {
-      /* and the pause button only when NOT editing */
+      /*
+       * and the pause button only when NOT editing 
+       */
       addButton(commandBox, "pause", NULL, NULL);
    }
-   /* Create viewport for list */
+   /*
+    * Create viewport for list 
+    */
    n = 0;
    XtSetArg(wargs[n], XtNfromVert, commandBox);
    ++n;
    viewport = XtCreateManagedWidget("viewport", viewportWidgetClass,
 				    topForm, wargs, n);
-   /* Create two lists inside a form */
+   /*
+    * Create two lists inside a form 
+    */
 
    n = 0;
    listForm = XtCreateManagedWidget("form", formWidgetClass, viewport, wargs, n);
-   /* The list of times */
+   /*
+    * The list of times 
+    */
    n = 0;
    XtSetArg(wargs[n], XtNlist, timeList);
    ++n;
    timelist_widget = XtCreateManagedWidget("times", listWidgetClass,
 					   listForm, wargs, n);
    XtAddCallback(timelist_widget, XtNcallback, notifycallback, NULL);
-   /* The list of names */
+   /*
+    * The list of names 
+    */
    n = 0;
    XtSetArg(wargs[n], XtNlist, nameList);
    ++n;
@@ -1032,41 +1256,61 @@ main(argc, argv)
 				       listForm, wargs, n);
    XtAddCallback(list_widget, XtNcallback, notifycallback, NULL);
    setIcon();
-   /* The following is only done when the TimeTracker is NOT an editor */
+   /*
+    * The following is only done when the TimeTracker is NOT an editor 
+    */
    if (timestring == NULL) {
       XtAddCallback(list_widget, XtNdestroyCallback, savewhendying, NULL);
-      /* Start clock ticking */
+      /*
+       * Start clock ticking 
+       */
       XtAppAddTimeOut(appContext, TICKPERIOD, clockTick, (XtPointer) NULL);
       XtAppAddTimeOut(appContext, SAVEPERIOD, saveOnclockTick, NULL);
-      /* Set the fatal error handler, so that we can save on being killed */
+      /*
+       * Set the fatal error handler, so that we can save on being killed 
+       */
       XtAppSetErrorHandler(appContext, gaspanddie);
       XSetIOErrorHandler(IOErrorHandler);
-      /* Set signal handlers */
+      /*
+       * Set signal handlers 
+       */
       signal(SIGINT, signalhandler);
       signal(SIGHUP, signalhandler);
       signal(SIGTERM, signalhandler);
       signal(SIGQUIT, signalhandler);
       signal(SIGPIPE, signalhandler);
    }
-   /* Install action procedures */
+   /*
+    * Install action procedures 
+    */
    RegisterActions();
-   /* Read the previous times for today, if any */
+   /*
+    * Read the previous times for today, if any 
+    */
    addprevtimes();
 
-   /* Select the first project by default */
+   /*
+    * Select the first project by default 
+    */
    if (!app_resources.start_paused) {
       XawListHighlight(list_widget, 0);
       XawListHighlight(timelist_widget, 0);
    }
    XtRealizeWidget(toplevel);
    purge_working_set();
-   /* Tell the old programmer that I have started */
+   /*
+    * Tell the old programmer that I have started 
+    */
 #ifndef DO_NOT_TELL_ABOUT_ME
    sayiamhere(title);
 #endif
-   /* Set total-display to current. MUST be after realize */
+   /*
+    * Set total-display to current. MUST be after realize 
+    */
    redisplayTime(currentProject());
    XtAppMainLoop(appContext);
-   return 0;			/* will never be reached, but Lint does not
-				 * know that */
+   return 0;			/*
+				 * will never be reached, but Lint does not
+				 * * know that 
+				 */
 }
